@@ -36,7 +36,7 @@ UNIVERSAL_PROFILE_CHECKS = \
   'com.google.fonts/check/valid_glyphnames',
   'com.google.fonts/check/unique_glyphnames',
 #  'com.google.fonts/check/glyphnames_max_length',
-
+  'com.google.fonts/check/family/vertical_metrics',
 ]
 
 @check(
@@ -794,8 +794,9 @@ def com_google_fonts_check_valid_glyphnames(ttFont):
     if len(bad_names) == 0:
       yield PASS, "Glyph names are all valid."
     else:
+      from fontbakery.utils import pretty_print_list
       yield FAIL, ("The following glyph names do not comply"
-                   " with naming conventions: {}"
+                   " with naming conventions: {}\n\n"
                    " A glyph name may be up to 31 characters in length,"
                    " must be entirely comprised of characters from"
                    " the following set:"
@@ -805,7 +806,8 @@ def com_google_fonts_check_valid_glyphnames(ttFont):
                    " such as the special character \".notdef\"."
                    " The glyph names \"twocents\", \"a1\", and \"_\""
                    " are all valid, while \"2cents\""
-                   " and \".twocents\" are not.").format(bad_names)
+                   " and \".twocents\" are not."
+                   "").format(pretty_print_list(bad_names))
 
 
 @check(
@@ -944,5 +946,49 @@ def com_google_fonts_check_ttx_roundtrip(font):
     os.remove(xml_file)
 
 
+@check(
+  id = 'com.google.fonts/check/family/vertical_metrics',
+  rationale="""
+  We want all fonts within a family to have the same vertical metrics so
+  their line spacing is consistent across the family.
+  """
+)
+def com_google_fonts_check_family_vertical_metrics(ttFonts):
+  """Each font in a family must have the same vertical metrics values."""
+  failed = []
+  vmetrics = {
+    "sTypoAscender": {},
+    "sTypoDescender": {},
+    "sTypoLineGap": {},
+    "usWinAscent": {},
+    "usWinDescent": {},
+    "ascent": {},
+    "descent": {}
+  }
+
+  for ttfont in ttFonts:
+      full_font_name = ttfont['name'].getName(4, 3, 1, 1033).toUnicode()
+      vmetrics['sTypoAscender'][full_font_name] = ttfont['OS/2'].sTypoAscender
+      vmetrics['sTypoDescender'][full_font_name] = ttfont['OS/2'].sTypoDescender
+      vmetrics['sTypoLineGap'][full_font_name] = ttfont['OS/2'].sTypoLineGap
+      vmetrics['usWinAscent'][full_font_name] = ttfont['OS/2'].usWinAscent
+      vmetrics['usWinDescent'][full_font_name] = ttfont['OS/2'].usWinDescent
+      vmetrics['ascent'][full_font_name] = ttfont['hhea'].ascent
+      vmetrics['descent'][full_font_name] = ttfont['hhea'].descent
+
+  for k, v in vmetrics.items():
+      metric_vals = set(vmetrics[k].values())
+      if len(metric_vals) != 1:
+          failed.append(k)
+
+  if failed:
+      for k in failed:
+        s = ["{}: {}".format(k, v) for k, v in vmetrics[k].items()]
+        yield FAIL, ("{} is not the same across the family:\n:"
+                     "{}".format(k, "\n".join(s)))
+  else:
+      yield PASS, "Vertical metrics are the same across the family"
+
+
 profile.auto_register(globals())
 profile.test_expected_checks(UNIVERSAL_PROFILE_CHECKS, exclusive=True)
