@@ -20,6 +20,31 @@ from fontbakery.checkrunner import (
 check_statuses = (ERROR, FAIL, SKIP, PASS, WARN, INFO, DEBUG)
 
 
+@pytest.fixture
+def montserrat_ttFonts():
+  paths = [
+    TEST_FILE("montserrat/Montserrat-Black.ttf"),
+    TEST_FILE("montserrat/Montserrat-BlackItalic.ttf"),
+    TEST_FILE("montserrat/Montserrat-Bold.ttf"),
+    TEST_FILE("montserrat/Montserrat-BoldItalic.ttf"),
+    TEST_FILE("montserrat/Montserrat-ExtraBold.ttf"),
+    TEST_FILE("montserrat/Montserrat-ExtraBoldItalic.ttf"),
+    TEST_FILE("montserrat/Montserrat-ExtraLight.ttf"),
+    TEST_FILE("montserrat/Montserrat-ExtraLightItalic.ttf"),
+    TEST_FILE("montserrat/Montserrat-Italic.ttf"),
+    TEST_FILE("montserrat/Montserrat-Light.ttf"),
+    TEST_FILE("montserrat/Montserrat-LightItalic.ttf"),
+    TEST_FILE("montserrat/Montserrat-Medium.ttf"),
+    TEST_FILE("montserrat/Montserrat-MediumItalic.ttf"),
+    TEST_FILE("montserrat/Montserrat-Regular.ttf"),
+    TEST_FILE("montserrat/Montserrat-SemiBold.ttf"),
+    TEST_FILE("montserrat/Montserrat-SemiBoldItalic.ttf"),
+    TEST_FILE("montserrat/Montserrat-Thin.ttf"),
+    TEST_FILE("montserrat/Montserrat-ThinItalic.ttf")
+  ]
+  return [TTFont(path) for path in paths]
+
+
 def test_check_family_single_directory():
   """ Fonts are all in the same directory. """
   from fontbakery.profiles.universal import com_google_fonts_check_family_single_directory as check
@@ -967,3 +992,14 @@ def test_check_os2_metrics_match_hhea(mada_ttFonts):
   status, message = list(check(ttFont))[-1]
   assert status == FAIL and message.code == "descender"
 
+
+def test_check_family_vertical_metrics(montserrat_ttFonts):
+  from fontbakery.profiles.universal import com_google_fonts_check_family_vertical_metrics as check
+  print("Test pass with multiple good fonts...")
+  status, message = list(check(montserrat_ttFonts))[-1]
+  assert status == PASS
+
+  print("Test fail with one bad font that has one different vertical metric val...")
+  montserrat_ttFonts[0]['OS/2'].usWinAscent = 4000
+  status, message = list(check(montserrat_ttFonts))[-1]
+  assert status == FAIL
